@@ -476,7 +476,10 @@ CreatorCES <- function(silentText=FALSE,...){
     }
 
     if(!is.null(xreg)){
-        xreg <- matxt[,xregNames];
+        if(ncol(matat)==1){
+            colnames(matxt) <- colnames(matat) <- xregNames;
+        }
+        xreg <- matxt;
     }
 
 # Prepare for fitting
