@@ -55,3 +55,9 @@ test_that("Check exogenous variables for SSARIMA on N1457", {
     expect_equal(suppressWarnings(ssarima(y, h=18, holdout=TRUE, xreg=x, silent=TRUE)$model), testModel$model);
     expect_equal(suppressWarnings(forecast(testModel, h=18, holdout=FALSE)$model), testModel$model);
 })
+
+# Test selection of exogenous with Auto.SSARIMA
+testModel <- auto.ssarima(y, orders=list(ar=3,i=2,ma=3), lags=1, h=18, holdout=TRUE, xreg=x, xregDo="select", silent=TRUE)
+test_that("Select exogenous variables for auto SSARIMA on N1457", {
+    expect_length((testModel$xreg),69);
+})
